@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp qw{ carp croak };
 
-our $VERSION = 0.2;
+our $VERSION = 0.21;
 
 use Webservice::OVH::Email::Domain::Domain::Task::Account;
 use Webservice::OVH::Email::Domain::Domain::Task::Mailinglist;
@@ -24,7 +24,7 @@ sub _new {
 
     my $self = bless {
         _module            => $module,
-        _api_wrapper       => $api_wrapper,
+        _wrapper       => $api_wrapper,
         _tasks_account     => {},
         _tasks_mailinglist => {},
         _tasks_redirection => {},
@@ -44,7 +44,7 @@ sub domain {
 sub mailinglist_tasks {
 
     my ($self)      = @_;
-    my $api         = $self->{_api_wrapper};
+    my $api         = $self->{_wrapper};
     my $domain_name = $self->domain->name;
 
     my $response = $api->rawCall( method => 'get', path => "/email/domain/$domain_name/task/mailinglist", noSignature => 0 );
@@ -68,7 +68,7 @@ sub mailinglist_task_by_id {
 
     croak "Missing id" unless $id;
 
-    my $api               = $self->{_api_wrapper};
+    my $api               = $self->{_wrapper};
     my $from_object_array = $self->{_tasks_mailinglist}{$id} if $self->{_tasks_mailinglist}{$id} && $self->{_tasks_mailinglist}{$id}->is_valid;
     my $account           = $self->{_tasks_mailinglist}{$id} = $from_object_array || Webservice::OVH::Email::Domain::Domain::Task::Mailinglist->_new_existing( wrapper => $api, domain => $self->domain, id => $id, module => $self->{_module} );
 
@@ -82,7 +82,7 @@ sub mailinglist_tasks_by_name {
     croak "Missing mailinglist_name" unless $mailinglist_name;
 
     my $domain_name = $self->domain->name;
-    my $api         = $self->{_api_wrapper};
+    my $api         = $self->{_wrapper};
 
     my $response = $api->rawCall( method => 'get', path => sprintf( "/email/domain/$domain_name/task/mailinglist?account=%s", $mailinglist_name ), noSignature => 0 );
     croak $response->error if $response->error;
@@ -105,7 +105,7 @@ sub account_tasks {
 
     my ($self) = @_;
 
-    my $api         = $self->{_api_wrapper};
+    my $api         = $self->{_wrapper};
     my $domain_name = $self->domain->name;
 
     my $response = $api->rawCall( method => 'get', path => "/email/domain/$domain_name/task/account", noSignature => 0 );
@@ -129,8 +129,8 @@ sub account_task_by_id {
 
     croak "Missing id" unless $id;
 
-    my $api               = $self->{_api_wrapper};
-    my $from_object_array = $self->{_tasks_account}{$id} if $self->{_tasks_account}{$id} && $self->{_tasks_account}{$id}->is_valid;
+    my $api               = $self->{_wrapper};
+    my $from_object_array = $self->{_tasks_account}{$id} if $self->{_tasks_account}{$id};
     my $account           = $self->{_tasks_account}{$id} = $from_object_array || Webservice::OVH::Email::Domain::Domain::Task::Account->_new_existing( wrapper => $api, domain => $self->domain, id => $id, module => $self->{_module} );
 
     return $account;
@@ -143,7 +143,7 @@ sub account_tasks_by_name {
     croak "Missing mailinglist_name" unless $account_name;
 
     my $domain_name = $self->domain->name;
-    my $api         = $self->{_api_wrapper};
+    my $api         = $self->{_wrapper};
 
     my $response = $api->rawCall( method => 'get', path => sprintf( "/email/domain/$domain_name/task/account?name=%s", $account_name ), noSignature => 0 );
     croak $response->error if $response->error;
@@ -166,7 +166,7 @@ sub redirection_tasks {
 
     my ($self) = @_;
 
-    my $api         = $self->{_api_wrapper};
+    my $api         = $self->{_wrapper};
     my $domain_name = $self->domain->name;
 
     my $response = $api->rawCall( method => 'get', path => "/email/domain/$domain_name/task/redirection", noSignature => 0 );
@@ -190,7 +190,7 @@ sub redirection_task_by_id {
 
     croak "Missing id" unless $id;
 
-    my $api               = $self->{_api_wrapper};
+    my $api               = $self->{_wrapper};
     my $from_object_array = $self->{_tasks_redirection}{$id} if $self->{_tasks_redirection}{$id} && $self->{_tasks_redirection}{$id}->is_valid;
     my $account           = $self->{_tasks_redirection}{$id} = $from_object_array || Webservice::OVH::Email::Domain::Domain::Task::Redirection->_new_existing( wrapper => $api, domain => $self->domain, id => $id, module => $self->{_module} );
 
@@ -204,7 +204,7 @@ sub redirection_tasks_by_name {
     croak "Missing mailinglist_name" unless $redirection_id;
 
     my $domain_name = $self->domain->name;
-    my $api         = $self->{_api_wrapper};
+    my $api         = $self->{_wrapper};
 
     my $response = $api->rawCall( method => 'get', path => sprintf( "/email/domain/$domain_name/task/redirection?account=%s", $redirection_id ), noSignature => 0 );
     croak $response->error if $response->error;
