@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp qw{ carp croak };
 
-our $VERSION = 0.2;
+our $VERSION = 0.21;
 
 sub _new_existing {
 
@@ -21,7 +21,7 @@ sub _new_existing {
     my $domain      = $params{domain};
     my $domain_name = $domain->name;
 
-    my $self = bless { _module => $module, _valid => 1, _api_wrapper => $api_wrapper, _id => $id, _properties => undef, _domain => $domain }, $class;
+    my $self = bless { _module => $module, _valid => 1, _wrapper => $api_wrapper, _id => $id, _properties => undef, _domain => $domain }, $class;
 
     return $self;
 }
@@ -43,7 +43,7 @@ sub properties {
 
     my $domain_name = $self->{_domain}->name;
     my $id          = $self->{_id};
-    my $api_wrapper = $self->{_api_wrapper};
+    my $api_wrapper = $self->{_wrapper};
 
     my $response = $api_wrapper->rawCall( method => 'get', path => "/email/domain/$domain_name/task/mailinglist/$id", noSignature => 0 );
     carp $response->error if $response->error;
@@ -64,7 +64,8 @@ sub account {
 
     my ($self) = @_;
 
-    croak "Invalid" unless $self->is_valid;
+    $self->properties unless $self->{_properties};
+    return unless $self->{_valid};
 
     return $self->{_properties}{account};
 }
@@ -73,7 +74,8 @@ sub language {
 
     my ($self) = @_;
 
-    croak "Invalid" unless $self->is_valid;
+    $self->properties unless $self->{_properties};
+    return unless $self->{_valid};
 
     return $self->{_properties}{language};
 }
@@ -82,8 +84,6 @@ sub id {
 
     my ($self) = @_;
 
-    croak "Invalid" unless $self->is_valid;
-
     return $self->{_id};
 }
 
@@ -91,8 +91,6 @@ sub domain {
 
     my ($self) = @_;
 
-    croak "Invalid" unless $self->is_valid;
-
     return $self->{_domain};
 }
 
@@ -100,7 +98,8 @@ sub date {
 
     my ($self) = @_;
 
-    croak "Invalid" unless $self->is_valid;
+    $self->properties unless $self->{_properties};
+    return unless $self->{_valid};
 
     return $self->{_properties}{date};
 }
@@ -109,7 +108,8 @@ sub action {
 
     my ($self) = @_;
 
-    croak "Invalid" unless $self->is_valid;
+    $self->properties unless $self->{_properties};
+    return unless $self->{_valid};
 
     return $self->{_properties}{action};
 }
